==> piwigo-11.5.0.zip: piwigo/language/ja_JP/upgrade.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+



$lang['Upgrade'] = 'アップグレード';
$lang['This page proposes to upgrade your database corresponding to your old version of Piwigo to the current version. The upgrade assistant thinks you are currently running a <strong>release %s</strong> (or equivalent).'] = 'このページであなたのデータベースをアップグレードするように推薦しています（旧Piwigoのデータベースから、現在版）。
アップグレード・アシスタントはあなたが現在<strong>release %s</strong> (またはそれと同等)を使っています。';
$lang['Upgrade from version %s to %s'] = 'バージョン %s から %s にアップグレードする';
$lang['Statistics'] = '統計';
$lang['total upgrade time'] = '合計アップグレード時間';
$lang['total SQL time'] = '合計SQL時間';
$lang['SQL queries'] = 'SQLクエリー';
$lang['Upgrade informations'] = '更新情報';
$lang['Perform a maintenance check in [Administration>Tools>Maintenance] if you encounter any problem.'] = '問題がある場合、[管理 > ツール > メンテナンス] でメンテナンスチェックを実行してください。';
$lang['Only administrator can run upgrade: please sign in below.'] = '管理者のみアップグレードを実行できます: 以下でログインしてください。';
$lang['You do not have access rights to run upgrade'] = 'あなたには、アップグレードを実行する権限がありません。';
$lang['All sub-albums of private albums become private'] = 'プライベートアルバムに含まれるすべてのサブアルバムがプライベートにされました。';
$lang['User permissions and group permissions have been erased'] = 'ユーザパーミッションおよびグループパーミッションが削除されました。';
$lang['Only thumbnails prefix and webmaster mail address have been saved from previous configuration'] = '以前の設定より、サムネイル接頭辞およびウェブマスターのメールアドレスのみ保存されました。';
$lang['As a precaution, following plugins have been deactivated. You must check for plugins upgrade before reactiving them:'] = '予防措置として、次のプラグインは無効になりました。プラグインを有効にする前に、プラグインのアップグレードを確認してください。:';
$lang['In <i>%s</i>, before <b>?></b>, insert:'] = '<i>%s</i>に、 <b>?></b>の前に入力:';
$lang['As a precaution, following themes have been deactivated. You must check for themes upgrade before reactiving them:'] = '予防措置として、次のテーマが無効になりました。テーマを有効にする前に、アップグレードを確認してください。：';
$lang['Discover what\'s new in Piwigo %s'] = 'Piwigo %s の新しい点を見つける';

==> piwigo-15.6.0.zip: piwigo/language/ja_JP/upgrade.lang.php <==
<?php
// +-----------------------------------------------------------------------+
// | This file is part of Piwigo.                                          |
// |                                                                       |
// | For copyright and license information, please view the COPYING.txt    |
// | file that was distributed with this source code.                      |
// +-----------------------------------------------------------------------+



$lang['Upgrade'] = 'アップグレード';
$lang['This page proposes to upgrade your database corresponding to your old version of Piwigo to the current version. The upgrade assistant thinks you are currently running a <strong>release %s</strong> (or equivalent).'] = 'このページであなたのデータベースをアップグレードするように推薦しています（旧Piwigoのデータベースから、現在版）。
アップグレード・アシスタントはあなたが現在<strong>release %s</strong> (またはそれと同等)を使っています。';
$lang['Upgrade from version %s to %s'] = 'バージョン %s から %s へのアップグレード';
$lang['Statistics'] = '統計';
$lang['total upgrade time'] = '合計アップグレード時間';
$lang['total SQL time'] = '合計SQL時間';
$lang['SQL queries'] = 'SQLクエリー';
$lang['Upgrade informations'] = '更新情報';
$lang['Perform a maintenance check in [Administration>Tools>Maintenance] if you encounter any problem.'] = '問題がある場合、[管理 > ツール > メンテナンス] でメンテナンスチェックを実行してください。';
$lang['Only administrator can run upgrade: please sign in below.'] = '管理者のみアップグレードを実行できます: 以下でログインしてください。';
$lang['You do not have access rights to run upgrade'] = 'あなたには、アップグレードを実行する権限がありません。';
$lang['All sub-albums of private albums become private'] = 'プライベートアルバムに含まれるすべてのサブアルバムがプライベートにされました。';
$lang['User permissions and group permissions have been erased'] = 'ユーザパーミッションおよびグループパーミッションが削除されました。';
$lang['Only thumbnails prefix and webmaster mail address have been saved from previous configuration'] = '以前の設定より、サムネイル接頭辞およびウェブマスターのメールアドレスのみ保存されました。';
$lang['As a precaution, following plugins have been deactivated. You must check for plugins upgrade before reactiving them:'] = '予防措置として、次のプラグインは無効になりました。プラグインを有効にする前に、プラグインのアップグレードを確認してください。:';
$lang['In <i>%s</i>, before <b>?></b>, insert:'] = '<i>%s</i>に、 <b>?></b>の前に入力:';
$lang['As a precaution, following themes have been deactivated. You must check for themes upgrade before reactiving them:'] = '予防措置として、次のテーマが無効になりました。テーマを有効にする前に、アップグレードを確認してください。：';
$lang['Discover what\'s new in Piwigo %s'] = 'Piwigo %s の新しい点を見つける';
